@@ -6,15 +6,32 @@ import git
 import os
 
 
-@click.command()
+@click.command(short_help = "Create Git repo and GitHub remote")
 @click.pass_context
-@click.option('-u', '--user', 'user_name' )
-@click.option('-p', '--password', 'password', hide_input=True)
-@click.option('-l', '--local', is_flag=True)
-@click.option('-r', '--repo-name')
-@click.option('--ssh', is_flag=True)
-def init(ctx, user_name, password,local, repo_name, ssh):
-    "Create git repo and github remote"
+@click.option('-u', '--user', 'user_name', help = "GitHub username")
+@click.option('-p', '--password', 'password', hide_input=True, help = "GitHub password")
+@click.option('-l', '--local', is_flag=True, help = "Init repo locally")
+@click.option('-n', '--name', help = "Repository's name")
+@click.option('--ssh', is_flag=True, help = "Use ssh authentication")
+def init(ctx, user_name, password,local, name, ssh):
+    """
+    Create git repo and github remote
+
+    If you don't want to create the repo in your GitHub account run:
+
+        $ gt init -l
+
+    You can use ssh authentication with 
+
+        $ gt init --ssh
+
+    (To enable ssh authentication follow this tutorial https://docs.github.com/en/github/authenticating-to-github/connecting-to-github-with-ssh)
+
+    You can also provide your repo's information in one step instead of waiting for the prompt with: 
+
+        $ gt init --name <repo name> --user <GitHub user> --password <GitHub password>
+
+    """
     if is_initialized_repo():
         click.echo('This is already a git repo!')
         return
@@ -28,14 +45,14 @@ def init(ctx, user_name, password,local, repo_name, ssh):
     if not password:
         password = click.prompt('Password', hide_input=True)
 
-    if not repo_name:
-        repo_name = click.prompt('Repo name')
+    if not name:
+        name = click.prompt('Repo name')
     
     try:
         g = Github(user_name, password)
         user = g.get_user()
         click.echo('Creating github repo...')
-        remote_repo = user.create_repo(repo_name)
+        remote_repo = user.create_repo(name)
     except GithubException as e:
         error_code = e.args[0]
         if error_code == 401 :
